﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Ozeki.VoIP.SDP;

namespace MessageManipulatorExample
{
    /// <summary>
    /// Replaces the value of the "Connection Information" field of the incoming and outgoing message to a custom IP address.
    /// </summary>
    class SDP_ConnectionManipulator : ISDPMessageManipulator
    {
        public string CustomInValue { get; set; }
        public string CustomOutValue { get; set; }

        public string PerformReceivedMessage(string incomingMessage)
        {
            if (string.IsNullOrEmpty(CustomInValue))
                return null;

            return ReplaceConnection(incomingMessage, true);
        }

        public string PerformSendMessage(string outGoingMessage)
        {
            if (string.IsNullOrEmpty(CustomOutValue))
                return null;

            return ReplaceConnection(outGoingMessage, false);
        }

        /// <summary>
        /// Replaces the value of the "Connection Information" field of the incoming or outgoing message to a custom IP address.
        /// </summary>
        private string ReplaceConnection(string sdpMessage, bool incomingMessage)
        {
            string[] rows = sdpMessage.Split(new string[] { "\r\n" }, StringSplitOptions.RemoveEmptyEntries);

            for (int i = 0; i < rows.Length; i++)
            {
                // Connection Information header: c=IN IP4 192.168.1.2
                if (rows[i].StartsWith("c="))
                {
                    string[] rowTokens = rows[i].Split(new char[] { ' ' });

                    rowTokens[2] = (incomingMessage) ? CustomInValue : CustomOutValue;

                    rows[i] = string.Join(" ", rowTokens);
                    break;
                }
            }

            string manipulatedSdp = string.Join("\r\n", rows);
            return manipulatedSdp;
        }
    }
}
